@@ -12,6 +12,10 @@ import os
 import signal
 import plistlib
 import py2app
+if __name__ == "__main__":
+    from tools import kill_child_processes
+else:
+    from .tools import kill_child_processes
 
 DIR_NAME=os.path.dirname(os.path.abspath(__file__))
 
@@ -27,8 +31,11 @@ class TestBasicApp (unittest.TestCase):
     # a base-class.
     @classmethod
     def setUpClass(cls):
+        kill_child_processes()
+
         env=os.environ.copy()
         pp = os.path.dirname(os.path.dirname(py2app.__file__))
+        env['TMPDIR'] = os.getcwd()
         if 'PYTHONPATH' in env:
             env['PYTHONPATH'] = pp + ':' + env['PYTHONPATH']
         else:
@@ -40,7 +47,7 @@ class TestBasicApp (unittest.TestCase):
             cwd = cls.app_dir,
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
-            close_fds=True,
+            close_fds=False,
             env=env)
         lines = p.communicate()[0]
         if p.wait() != 0:
@@ -55,6 +62,12 @@ class TestBasicApp (unittest.TestCase):
         if os.path.exists(os.path.join(cls.app_dir, 'dist')):
             shutil.rmtree(os.path.join(cls.app_dir, 'dist'))
 
+        time.sleep(2)
+
+    def tearDown(self):
+        kill_child_processes()
+        time.sleep(1)
+
     def assertContentsEqual(self, src_file, dst_file):
         fp = open(src_file, 'rb')
         src_data = fp.read()
