@@ -19,6 +19,11 @@ if __name__ == "__main__":
 else:
     from .tools import kill_child_processes
 
+try:
+    unichr
+except NameError:
+    unichr = chr
+
 DIR_NAME=os.path.dirname(os.path.abspath(__file__))
 
 
